@@ -1,3 +1,4 @@
+
 /*****************************************************************************
 *
 * MODULE:       OGR driver 
@@ -18,15 +19,13 @@
 #include "globals.h"
 #include "proto.h"
 
-int
-db__driver_init ( int argc, char *argv[] )
+int db__driver_init(int argc, char *argv[])
 {
     init_error();
     return DB_OK;
 }
 
-int
-db__driver_finish()
+int db__driver_finish()
 {
     return DB_OK;
 }
