@@ -1,6 +1,9 @@
+#ifndef GRASS_GLOCALE_H
+#define GRASS_GLOCALE_H
+
 #include <grass/config.h>
 
-extern char * G_gettext(const char *, const char *);
+extern char *G_gettext(const char *, const char *) __attribute__((format_arg (2)));
 
 #if defined(HAVE_LIBINTL_H) && defined(USE_NLS)
 #include <libintl.h>
@@ -9,3 +12,4 @@ extern char * G_gettext(const char *, const char *);
 #define _(str) (str)
 #endif
 
+#endif
