@@ -14,12 +14,8 @@
 
 #include <stdlib.h>
 
-#ifdef __MINGW32__
-#include <process.h>
-#else
-#include <sys/wait.h>
-#endif
 #include <grass/dbmi.h>
+#include <grass/spawn.h>
 #include "macros.h"
 
 /*!
@@ -28,19 +24,17 @@
   <b>Note:</b> the management of the memory for the driver structure
   probably should be handled differently.
  
-  db_start_driver() could take a pointer to driver structure as
-  an argument, instead of returning the pointer to allocated
-  then there would be no hidden free required
+  db_start_driver() could take a pointer to driver structure as an
+  argument, instead of returning the pointer to allocated then there
+  would be no hidden free required
 
-  \param driver db driver
+  \param driver pointer to dbDriver to be freed
 
-  \return status (?)
+  \return 0 on sucess
+  \return -1 on error
 */
 int db_shutdown_driver(dbDriver * driver)
 {
-#ifndef __MINGW32__
-    int pid;
-#endif
     int status;
 
 #ifdef __MINGW32__
@@ -58,14 +52,8 @@ int db_shutdown_driver(dbDriver * driver)
     /* wait for the driver to finish */
     status = -1;
 
-#ifdef __MINGW32__
-    /* TODO: convert status to something like from wait? */
-    _cwait(&status, driver->pid, WAIT_CHILD);
-#else
-    /* TODO: Should not be here waitpid() ? */
-    while ((pid = wait(&status)) > 0 && pid != driver->pid) {
-    }
-#endif
+    /* convert status according to return code of G_wait() */
+    status = G_wait(driver->pid) == -1 ? -1 : 0;
 
     driver->pid = 0;
 
