@@ -1,51 +1,65 @@
-/*
-* $Id: gsds.c,v 2.2 2006/02/09 03:08:57 glynn Exp $
-*/
+/*!
+   \file gsds.c
+
+   \brief OGSF library - dataset loading and management (lower level functions) 
+
+   GRASS OpenGL gsurf OGSF Library 
+
+   The idea here is to treat datasets as seperate objects, which SHOULD:
+   - allow easier reuse of data for different attributes.
+   - allow a mechanism for changing data and have changes reflected
+   in each attribute using that data.
+   - allow a mechanism to automatically update data when the data source
+   is changed.
+   - allow easier weaning from GRASS.
+   - allow easier use of shared memory between processes.
+
+   These structures are defined in gstypes.h:
+
+   <code>
+   typedef struct{
+   float *fb;
+   int *ib;
+   short *sb;
+   char *cb;
+   struct BM *bm;
+   } typbuff;
+   </code>
+
+   How about adding a transform func here, so GET_MAPATT would do an
+   on-the-fly transformation? Or even a transform func LIST!
+
+   <code>
+   typedef struct{
+   int data_id;
+   int dims[MAXDIMS];
+   int ndims;
+   int numbytes;
+   char unique_name[80];
+   typbuff databuff;
+   int changed;
+   int need_reload;
+   } dataset;
+   </code>
+
+   (C) 1999-2008 by the GRASS Development Team
+
+   This program is free software under the 
+   GNU General Public License (>=v2). 
+   Read the file COPYING that comes with GRASS
+   for details.
+
+   \author Bill Brown UI GMS Lab
+   \author Doxygenized by Martin Landa <landa.martin gmail.com> (May 2008)
+ */
 
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
 
+#include <grass/gis.h>
+#include <grass/glocale.h>
 #include <grass/gstypes.h>
 
-/*  The idea here is to treat datasets as seperate objects, which SHOULD:
- *     - allow easier reuse of data for different attributes.
- *     - allow a mechanism for changing data and have changes reflected
- *       in each attribute using that data.
- *     - allow a mechanism to automatically update data when the data source
- *       is changed.
- *     - allow easier weaning from GRASS.
- *     - allow easier use of shared memory between processes.
- * 
- * These structures are defined in gstypes.h:
- * typedef struct{
- *     float *fb;
- *     int *ib;
- *     short *sb;
- *     char *cb;
- *     struct BM *bm;
- * } typbuff;
-  How about adding a transform func here, so GET_MAPATT would do an
-  on-the-fly transformation? Or even a transform func LIST!
- * 
- * typedef struct{
- *     int data_id;
- *     int dims[MAXDIMS];
- *     int ndims;
- *     int numbytes;
- *     char unique_name[80];
- *     typbuff databuff;
- *     int changed;
- *     int need_reload;
- * } dataset;
- *
- * 
-*/
-
-/*
-#define TRACE_FUNCS
-*/
-
 #define LUCKY 33
 #define BLOC 20
 #define MAX_DS 100
@@ -64,7 +78,9 @@ static int Cur_id = LUCKY;
 static int Cur_max;
 static int Tot_mem = 0;
 
-/******************************************************************/
+/*!
+   \brief Initialize gsds
+ */
 static int init_gsds(void)
 {
     int i;
@@ -79,22 +95,31 @@ static int init_gsds(void)
     return (1);
 }
 
-/******************************************************************/
+/*!
+   \brief Check numsets
+
+   \return 0 numset < cur_max
+ */
 static int check_numsets(void)
 {
     if (Numsets < Cur_max) {
 	return (0);
     }
 
-    fprintf(stderr, "maximum number of datasets exceeded\n");
-
-    exit(0);
+    G_fatal_error(_("Maximum number of datasets exceeded"));
 
     /* This return statement keeps compilers happy, it is never executed */
     return (0);
 }
 
-/******************************************************************/
+/*!
+   \brief Get dataset
+
+   \param id data id
+
+   \return pointer to dataset struct
+   \return NULL dataset not found
+ */
 static dataset *get_dataset(int id)
 {
     int i;
@@ -108,7 +133,14 @@ static dataset *get_dataset(int id)
     return (NULL);
 }
 
-/******************************************************************/
+/*!
+   \brief Get type
+
+   \param ds pointer to dataset struct
+
+   \return type code
+   \return -1 unsupported type
+ */
 static int get_type(dataset * ds)
 {
     if (ds) {
@@ -136,19 +168,24 @@ static int get_type(dataset * ds)
     return (-1);
 }
 
-/******************************************************************/
-/* returns handle to gsds.   
-   successive calls will continue search until "begin" is set   
+/*!
+   \brief Get handle to gsds.   
+
+   Successive calls will continue search until "begin" is set   
    (problem here is, unique_name no longer uniquely identifies
    dataset, since changes may be made; but unique_name should still
    be useful for reloading dataset)
    changes & types are set to actual for dataset if found.
 
-    changes, types  acceptable changes & types, flags may be or'd
-		    not changed is assumed to always be acceptable
-    begin           flag to indicate search from beginning
-*/
-int gsds_findh(char *name, IFLAG * changes, IFLAG * types, int begin)
+   \param name
+   \param changes,types  acceptable changes & types, flags may be or'd
+   not changed is assumed to always be acceptable
+   \param begin flag to indicate search from beginning
+
+   \return data id
+   \return -1 not found
+ */
+int gsds_findh(const char *name, IFLAG * changes, IFLAG * types, int begin)
 {
     static int i;
     int start;
@@ -171,9 +208,15 @@ int gsds_findh(char *name, IFLAG * changes, IFLAG * types, int begin)
     return (-1);
 }
 
-/******************************************************************/
-/* returns handle to gsds */
-int gsds_newh(char *name)
+/*!
+   \brief Get handle to gsds
+
+   \param name raster map name
+
+   \return -1 on failure
+   \return data id
+ */
+int gsds_newh(const char *name)
 {
     dataset *new;
     static int first = 1;
@@ -204,7 +247,7 @@ int gsds_newh(char *name)
 	    new->dims[i] = 0;
 	}
 
-	strcpy(new->unique_name, name);
+	new->unique_name = G_store(name);
 	new->databuff.fb = NULL;
 	new->databuff.ib = NULL;
 	new->databuff.sb = NULL;
@@ -222,15 +265,24 @@ int gsds_newh(char *name)
     return (-1);
 }
 
-/******************************************************************/
-/* change_flag just tells us to set changed flag - doesn't prevent
-writing a buff thats's been gotten with change_flag == 0 (could return a
-copy, but willing to trust calling func for now) */
+/*!
+   \brief Get data buffer
+
+   Doesn't prevent writing a buff thats's been gotten with change_flag
+   == 0 (could return a copy, but willing to trust calling func for
+   now)
+
+   \param id dataset id
+   \param change_flag set changed flag
+
+   \return pointer to typbuff struct
+   \return NULL on failure
+ */
 typbuff *gsds_get_typbuff(int id, IFLAG change_flag)
 {
     dataset *ds;
 
-    if (ds = get_dataset(id)) {
+    if ((ds = get_dataset(id))) {
 	ds->changed = ds->changed | change_flag;
 	ds->need_reload = 0;
 
@@ -240,12 +292,19 @@ typbuff *gsds_get_typbuff(int id, IFLAG change_flag)
     return (NULL);
 }
 
-/******************************************************************/
+/*!
+   \brief Get name
+
+   \param id
+
+   \return name
+   \return NULL on failure
+ */
 char *gsds_get_name(int id)
 {
     int i;
     dataset *fds;
-    static char retstr[160];
+    static char retstr[GPATH_MAX];
 
     for (i = 0; i < Numsets; i++) {
 	if (Data[i]->data_id == id) {
@@ -259,24 +318,28 @@ char *gsds_get_name(int id)
     return (NULL);
 }
 
-/******************************************************************/
+/*!
+   \brief Free allocated dataset
+
+   \param id
+
+   \return 0 not found
+   \return 1 found
+ */
 int gsds_free_datah(int id)
 {
     int i, j, found = 0;
     dataset *fds;
 
-#ifdef TRACE_FUNCS
-    {
-	fprintf(stderr, "gsds_free_datah\n");
-    }
-#endif
+    G_debug(3, "gsds_free_datah");
 
     for (i = 0; i < Numsets; i++) {
 	if (Data[i]->data_id == id) {
 	    found = 1;
 	    fds = Data[i];
 	    free_data_buffs(fds, ATTY_ANY);
-	    strcpy(fds->unique_name, "");
+	    G_free((void *)fds->unique_name);
+	    fds->unique_name = NULL;
 	    fds->data_id = 0;
 
 	    for (j = i; j < (Numsets - 1); j++) {
@@ -294,7 +357,15 @@ int gsds_free_datah(int id)
     return (found);
 }
 
-/******************************************************************/
+/*!
+   \brief Free allocated buffer
+
+   \param id dataset id
+   \param typ data type
+
+   \return 0 not found
+   \return 1 found
+ */
 int gsds_free_data_buff(int id, int typ)
 {
     int i, found = 0;
@@ -311,7 +382,14 @@ int gsds_free_data_buff(int id, int typ)
     return (found);
 }
 
-/******************************************************************/
+/*!
+   \brief Free data buffer
+
+   \param ds pointer to dataset struct
+   \param typ data type
+
+   \return freed size
+ */
 int free_data_buffs(dataset * ds, int typ)
 {
     int nsiz = 1, i, siz, freed = 0;
@@ -377,28 +455,36 @@ int free_data_buffs(dataset * ds, int typ)
     Tot_mem -= freed;
     ds->numbytes -= freed;
 
-#ifdef DEBUG_MSG
-    {
-	if (freed) {
-	    fprintf(stderr, "freed data from id no. %d\n", ds->data_id);
-	    fprintf(stderr, "%.3f Kbytes freed, current total = %.3f\n",
-		    freed / 1000., Tot_mem / 1000.);
-	}
+    if (freed) {
+	G_debug(5, "free_data_buffs(): freed data from id no. %d",
+		ds->data_id);
+	G_debug(5,
+		"free_data_buffs(): %.3f Kbytes freed, current total = %.3f",
+		freed / 1000., Tot_mem / 1000.);
     }
-#endif
 
     return (freed);
 }
 
-/******************************************************************/
-/* allocates correct buffer according to type, keeps track of total mem */
-/* TODO: add ATTY_CONST */
+/*!
+   \brief Allocates correct buffer according to type, keeps track of total mem
+
+   \todo add ATTY_CONST
+
+   \param id dataset id
+   \param dims array of dimensions
+   \param ndims number of dimensions
+   \param type data type
+
+   \return
+ */
 int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 {
     dataset *ds;
-    int i, siz = 1;
+    int i;
+    size_t siz = 1;
 
-    if (ds = get_dataset(id)) {
+    if ((ds = get_dataset(id))) {
 	/*
 	   free_data_buffs(ds); 
 	   careful here - allowing > 1 type to coexist (for float -> color conv.)
@@ -444,7 +530,8 @@ int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 	    siz *= sizeof(char);
 
 	    if (siz) {
-		if (NULL == (ds->databuff.cb = (unsigned char *) malloc(siz))) {
+		if (NULL ==
+		    (ds->databuff.cb = (unsigned char *)G_malloc(siz))) {
 		    return (-1);
 		}
 	    }
@@ -458,7 +545,7 @@ int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 	    siz *= sizeof(short);
 
 	    if (siz) {
-		if (NULL == (ds->databuff.sb = (short *) malloc(siz))) {
+		if (NULL == (ds->databuff.sb = (short *)G_malloc(siz))) {
 		    return (-1);
 		}
 	    }
@@ -472,7 +559,7 @@ int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 	    siz *= sizeof(int);
 
 	    if (siz) {
-		if (NULL == (ds->databuff.ib = (int *) malloc(siz))) {
+		if (NULL == (ds->databuff.ib = (int *)G_malloc(siz))) {
 		    return (-1);
 		}
 	    }
@@ -486,7 +573,7 @@ int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 	    siz *= sizeof(float);
 
 	    if (siz) {
-		if (NULL == (ds->databuff.fb = (float *) malloc(siz))) {
+		if (NULL == (ds->databuff.fb = (float *)G_malloc(siz))) {
 		    return (-1);
 		}
 	    }
@@ -506,44 +593,62 @@ int gsds_alloc_typbuff(int id, int *dims, int ndims, int type)
 	ds->ndims = ndims;
 	Tot_mem += siz;
 
-#ifdef DEBUG_MSG
-	{
-	    fprintf(stderr, "%f Kbytes allocated, current total = %f\n",
-		    siz / 1000., Tot_mem / 1000.);
-	}
-#endif
+	G_debug(5,
+		"gsds_alloc_typbuff(): %f Kbytes allocated, current total = %f",
+		siz / 1000., Tot_mem / 1000.);
 
-	return (siz);
+	return (1);
     }
 
     return (-1);
 }
 
-/******************************************************************/
+/*!
+   \brief ADD
+
+   \param id
+
+   \return -1 on error
+   \return 
+ */
 int gsds_get_changed(int id)
 {
     dataset *ds;
 
-    if (ds = get_dataset(id)) {
-	return ((int) ds->changed);
+    if ((ds = get_dataset(id))) {
+	return ((int)ds->changed);
     }
 
     return (-1);
 }
 
-/******************************************************************/
+/*!
+   \brief ADD
+
+   \param id
+   \param reason
+
+   \return -1 on error
+   \return
+ */
 int gsds_set_changed(int id, IFLAG reason)
 {
     dataset *ds;
 
-    if (ds = get_dataset(id)) {
+    if ((ds = get_dataset(id))) {
 	ds->changed = reason;
     }
 
     return (-1);
 }
 
-/******************************************************************/
+/*!                                             
+   \brief ADD
+
+   \param id
+
+   \return
+ */
 int gsds_get_type(int id)
 {
     dataset *ds;
