@@ -33,6 +33,11 @@
 #define	POINT2D_C
 #include <grass/interpf.h>
 
+/* needed for AIX */
+#ifdef hz
+#undef hz
+#endif
+
 int IL_check_at_points_2d(struct interp_params *params, struct quaddata *data,	/* current region */
 			  double *b,	/* solution of linear equations */
 			  double *ertot,	/* total error */
@@ -114,7 +119,7 @@ int IL_check_at_points_2d(struct interp_params *params, struct quaddata *data,	/
 		sprintf(buf, ", %f", err);
 		db_append_string(&sql2, buf);
 		db_append_string(&sql2, ")");
-		G_debug(3, db_get_string(&sql2));
+		G_debug(3, "IL_check_at_points_2d: %s", db_get_string(&sql2));
 
 		if (db_execute_immediate(driver2, &sql2) != DB_OK) {
 		    db_close_database(driver2);
@@ -171,7 +176,7 @@ int IL_check_at_points_2d(struct interp_params *params, struct quaddata *data,	/
 	    sprintf(buf, ", %f", skip_err);
 	    db_append_string(&sql2, buf);
 	    db_append_string(&sql2, ")");
-	    G_debug(3, db_get_string(&sql2));
+	    G_debug(3, "IL_check_at_points_2d: %s", db_get_string(&sql2));
 
 	    if (db_execute_immediate(driver2, &sql2) != DB_OK) {
 		db_close_database(driver2);
