@@ -135,6 +135,9 @@ struct robject_list *Vedit_render_map(struct Map_info *Map,
 				     list_obj->nitems *
 				     sizeof(struct robject *));
 
+    G_debug(1, "Vedit_render_map(): -> nitems = %d",
+	    list_obj->nitems);
+
     Vect_destroy_list(list);
 
     return list_obj;
@@ -461,6 +464,7 @@ void draw_area(struct Map_info *Map, int area, struct robject_list *list)
     /* get area's boundary */
     Vect_get_area_points(Map, area, state.Points);
     robj = robj_alloc(TYPE_AREA, state.Points->n_points);
+    robj->fid = centroid;
     robj_points(robj, state.Points);
     list_append(list, robj);
 
@@ -473,6 +477,7 @@ void draw_area(struct Map_info *Map, int area, struct robject_list *list)
 
 	Vect_get_isle_points(Map, isle, ipoints);
 	robj = robj_alloc(TYPE_ISLE, ipoints->n_points);
+	robj->fid = -1;
 	robj_points(robj, ipoints);
 	list_append(list, robj);
     }
