@@ -17,7 +17,8 @@ int error(char *a, char *b, char *c)
     if (isatty(0))
 	fprintf(stderr, "%s\n", msg);
     else
-	G_fatal_error(msg);
+	G_fatal_error("%s", msg);
+
     reject();
 
     return 0;
