@@ -3,10 +3,11 @@
  *
  * MODULE:	r.li.renyi
  *
- * PURPOSE:	brief calculates renyi's diversity index
+ * PURPOSE:	calculates renyi's diversity index
  *
  * AUTHOR(S):	Luca Delucchi, Fondazione Edmund Mach         
  *		Serena Pallecchi student of Computer Science University of Pisa (Italy)
+ *              Rewrite: Markus Metz
  *            	
  * COPYRIGHT:
  *		This program is free software under the GPL (>=v2)
@@ -21,16 +22,16 @@
 #include <grass/gis.h>
 #include <grass/glocale.h>
 
-#include "../r.li.daemon/defs.h"
+#include "../r.li.daemon/daemon.h"
 #include "../r.li.daemon/avlDefs.h"
 #include "../r.li.daemon/avl.h"
-#include "../r.li.daemon/daemon.h"
 
-double calculate(area_des ad, int fd, char **par, double *result);
+/* template is shannon */
 
-double calculateD(area_des ad, int fd, char **par, double *result);
-
-double calculateF(area_des ad, int fd, char **par, double *result);
+rli_func renyi;
+int calculate(int fd, struct area_entry *ad, char **par, double *result);
+int calculateD(int fd, struct area_entry *ad, char **par, double *result);
+int calculateF(int fd, struct area_entry *ad, char **par, double *result);
 
 int main(int argc, char *argv[])
 {
@@ -49,11 +50,9 @@ int main(int argc, char *argv[])
 
     raster = G_define_standard_option(G_OPT_R_MAP);
 
-    conf = G_define_option();
+    conf = G_define_standard_option(G_OPT_F_INPUT);
     conf->key = "conf";
     conf->description = _("Configuration file");
-    conf->type = TYPE_STRING;
-    conf->gisprompt = "old_file,file,input";
     conf->required = YES;
 
     alpha = G_define_option();
@@ -68,7 +67,7 @@ int main(int argc, char *argv[])
     if (G_parser(argc, argv))
 	exit(EXIT_FAILURE);
 
-    if (atoi(alpha->answer) == 1) {
+    if (atof(alpha->answer) == 1) {
 	G_fatal_error
 	    ("If alpha = 1 Renyi index is not defined. (Ricotta et al., 2003, Environ. Model. Softw.)");
 	exit(RLI_ERRORE);
@@ -83,34 +82,31 @@ int main(int argc, char *argv[])
     }
     return calculateIndex(conf->answer, renyi, par, raster->answer,
 			  output->answer);
-
 }
 
-int renyi(int fd, char **par, area_des ad, double *result)
+
+int renyi(int fd, char **par, struct area_entry *ad, double *result)
 {
-    char *mapset;
     int ris = RLI_OK;
     double indice = 0;
-    struct Cell_head hd;
 
-    mapset = G_find_cell(ad->raster, "");
-    if (G_get_cellhd(ad->raster, mapset, &hd) == -1)
-	return RLI_ERRORE;
+    if (!par)
+	G_fatal_error("par is NULL");
 
     switch (ad->data_type) {
     case CELL_TYPE:
 	{
-	    ris = calculate(ad, fd, par, &indice);
+	    ris = calculate(fd, ad, par, &indice);
 	    break;
 	}
     case DCELL_TYPE:
 	{
-	    ris = calculateD(ad, fd, par, &indice);
+	    ris = calculateD(fd, ad, par, &indice);
 	    break;
 	}
     case FCELL_TYPE:
 	{
-	    ris = calculateF(ad, fd, par, &indice);
+	    ris = calculateF(fd, ad, par, &indice);
 	    break;
 	}
     default:
@@ -118,40 +114,35 @@ int renyi(int fd, char **par, area_des ad, double *result)
 	    G_fatal_error("data type unknown");
 	    return RLI_ERRORE;
 	}
-
     }
 
-    if (ris != RLI_OK)
+    if (ris != RLI_OK) {
 	return RLI_ERRORE;
+    }
 
     *result = indice;
 
     return RLI_OK;
-
 }
 
 
-
-double calculate(area_des ad, int fd, char **par, double *result)
+int calculate(int fd, struct area_entry *ad, char **par, double *result)
 {
     CELL *buf;
     CELL corrCell;
     CELL precCell;
 
     int i, j;
-    int mask_fd = -1, *mask_buf;
+    int mask_fd = -1, *mask_buf = NULL;
     int ris = 0;
     int masked = FALSE;
-    int a = 0;			/* a=0 if all cells are null */
+
     long m = 0;
     long tot = 0;
     long zero = 0;
-    long totCorr = 0;
-    double indice = 0;
-    double somma = 0;
-    double p = 0;
-    double area = 0;
-    double t;
+    long totCorr = 1;
+
+    long area = 0;
 
     avl_tree albero = NULL;
     AVL_table *array;
@@ -172,8 +163,6 @@ double calculate(area_des ad, int fd, char **par, double *result)
     }
 
     G_set_c_null_value(&precCell, 1);
-
-
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -183,70 +172,70 @@ double calculate(area_des ad, int fd, char **par, double *result)
 	}
 
 	buf = RLI_get_cell_raster_row(fd, j + ad->y, ad);
+
 	for (i = 0; i < ad->cl; i++) {	/* for each cell in the row */
-	    area++;
 	    corrCell = buf[i + ad->x];
 
-	    if ((masked) && (mask_buf[i + ad->x] == 0)) {
+	    if ((masked) && (mask_buf[i] == 0)) {
 		G_set_c_null_value(&corrCell, 1);
-		area--;
 	    }
 
 	    if (!(G_is_null_value(&corrCell, uc.t))) {
-		a = 1;
-		if (G_is_null_value(&precCell, uc.t)) {
-		    precCell = corrCell;
-		}
-		if (corrCell != precCell) {
-		    if (albero == NULL) {
-			uc.val.c = precCell;
-			albero = avl_make(uc, totCorr);
-			if (albero == NULL) {
-			    G_fatal_error("avl_make error");
-			    return RLI_ERRORE;
-			}
-			else
-			    m++;
-		    }
-		    else {
-			uc.val.c = precCell;
-			ris = avl_add(&albero, uc, totCorr);
-			switch (ris) {
-			case AVL_ERR:
-			    {
-				G_fatal_error("avl_add error");
-				return RLI_ERRORE;
-			    }
-			case AVL_ADD:
-			    {
-				m++;
-				break;
-			    }
-			case AVL_PRES:
-			    {
-				break;
-			    }
-			default:
-			    {
-				G_fatal_error("avl_make unknown error");
-				return RLI_ERRORE;
-			    }
-			}
-		    }
-		    totCorr = 1;
-		}		/* endif not equal cells */
-		else {		/*equal cells */
-
-		    totCorr++;
-		}
-		precCell = corrCell;
+		/* total patch area */
+		area++;
 	    }
 
+	    if (!(G_is_null_value(&precCell, uc.t)) &&
+		corrCell == precCell) {
+
+		totCorr++;
+	    }
+	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+		     corrCell != precCell) {
+		
+		/* add precCell to search tree */
+		if (albero == NULL) {
+		    uc.val.c = precCell;
+		    albero = avl_make(uc, totCorr);
+		    if (albero == NULL) {
+			G_fatal_error("avl_make error");
+			return RLI_ERRORE;
+		    }
+		    m++;
+		}
+		else {
+		    uc.val.c = precCell;
+		    ris = avl_add(&albero, uc, totCorr);
+		    switch (ris) {
+		    case AVL_ERR:
+			{
+			    G_fatal_error("avl_add error");
+			    return RLI_ERRORE;
+			}
+		    case AVL_ADD:
+			{
+			    m++;
+			    break;
+			}
+		    case AVL_PRES:
+			{
+			    break;
+			}
+		    default:
+			{
+			    G_fatal_error("avl_make unknown error");
+			    return RLI_ERRORE;
+			}
+		    }
+		}
+		totCorr = 1;
+	    }		/* endif not equal cells */
+	    precCell = corrCell;
 	}
     }
 
-    /*last closing */
-    if (a != 0) {
+    /* last closing */
+    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.c = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -282,68 +271,79 @@ double calculate(area_des ad, int fd, char **par, double *result)
 	    }
 	}
     }
-    array = G_malloc(m * sizeof(AVL_tableRow));
-    if (array == NULL) {
-	G_fatal_error("malloc array failed");
-	return RLI_ERRORE;
-    }
-    tot = avl_to_array(albero, zero, array);
-    if (tot != m) {
-	G_warning("avl_to_array unaspected value. the result could be wrong");
-	return RLI_ERRORE;
+
+    if (area > 0) {
+	double alpha;
+	double pi;
+	double t;
+	double sum, sum2;
+
+	alpha = atof(par[0]);
+
+	array = G_malloc(m * sizeof(AVL_tableRow));
+	if (array == NULL) {
+	    G_fatal_error("malloc array failed");
+	    return RLI_ERRORE;
+	}
+	tot = avl_to_array(albero, zero, array);
+	if (tot != m) {
+	    G_warning("avl_to_array unexpected value. the result could be wrong");
+	    return RLI_ERRORE;
+	}
+
+	/* calculate renyi index */
+	sum = 0;
+	sum2 = 0;
+	for (i = 0; i < m; i++) {
+	    t = array[i]->tot;
+	    pi = t / area;
+	    sum += pow(pi, alpha);
+	    sum2 += pi;
+	}
+	G_free(array);
+
+	/* correction for numerical instability */
+	if (sum2 != 1)
+	    sum += 1 - sum2;
+
+	if ((alpha < 1 && sum < 1) || (alpha > 1 && sum > 1)) {
+	    G_warning("Renyi index calculation reached numerical instability. "
+	              "This can happen with alpha close to 1. The result will be set to zero.");
+	    sum = 1;
+	}
+
+	*result = (1 / (1 - alpha)) * log(sum);
     }
+    else
+	G_set_d_null_value(result, 1);
 
-    char *sval;
-
-    sval = par[0];
-    double alpha_double;
-
-    alpha_double = (double)atof(sval);
-    /* claculate index summary */
-    for (i = 0; i < m; i++) {
-	t = (double)(array[i]->tot);
-	p = t / area;
-	G_debug(1, "Valore p: %g, valore pow: %g", p, pow(p, alpha_double));
-	somma = somma + pow(p, alpha_double);
-    }
-
-    indice = (1 / (1 - alpha_double)) * log(somma);
-    if (isnan(indice) || isinf(indice)) {
-	indice = -1;
-    }
-    G_debug(1, "Valore somma: %g Valore indice: %g", somma, indice);
-
-    *result = indice;
-
-
-    G_free(array);
-    if (masked)
+    avl_destroy(albero);
+    if (masked) {
+	close(mask_fd);
 	G_free(mask_buf);
+    }
 
     return RLI_OK;
 }
 
 
-double calculateD(area_des ad, int fd, char **par, double *result)
+int calculateD(int fd, struct area_entry *ad, char **par, double *result)
 {
     DCELL *buf;
     DCELL corrCell;
     DCELL precCell;
 
     int i, j;
-    int mask_fd = -1, *mask_buf;
+    int mask_fd = -1, *mask_buf = NULL;
     int ris = 0;
     int masked = FALSE;
-    int a = 0;			/* a=0 if all cells are null */
+
     long m = 0;
     long tot = 0;
     long zero = 0;
-    long totCorr = 0;
-    double indice = 0;
-    double somma = 0;
-    double p = 0;
-    double area = 0;
-    double t;
+    long totCorr = 1;
+
+    long area = 0;
 
     avl_tree albero = NULL;
     AVL_table *array;
@@ -357,14 +357,13 @@ double calculateD(area_des ad, int fd, char **par, double *result)
 	    return RLI_ERRORE;
 	mask_buf = G_malloc(ad->cl * sizeof(int));
 	if (mask_buf == NULL) {
-	    G_fatal_error("malloc mask_buffailed");
+	    G_fatal_error("malloc mask_buf failed");
 	    return RLI_ERRORE;
 	}
 	masked = TRUE;
     }
 
     G_set_d_null_value(&precCell, 1);
-
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -375,71 +374,69 @@ double calculateD(area_des ad, int fd, char **par, double *result)
 
 	buf = RLI_get_dcell_raster_row(fd, j + ad->y, ad);
 
-	for (i = 0; i < ad->cl; i++) {	/* for each dcell in the row */
-	    area++;
+	for (i = 0; i < ad->cl; i++) {	/* for each cell in the row */
 	    corrCell = buf[i + ad->x];
 
-	    if (masked && mask_buf[i + ad->x] == 0) {
+	    if ((masked) && (mask_buf[i] == 0)) {
 		G_set_d_null_value(&corrCell, 1);
-		area--;
 	    }
 
 	    if (!(G_is_null_value(&corrCell, uc.t))) {
-		a = 1;
-
-		if (G_is_null_value(&precCell, uc.t)) {
-		    precCell = corrCell;
-		}
-		if (corrCell != precCell) {
-		    if (albero == NULL) {
-			uc.val.dc = precCell;
-			albero = avl_make(uc, totCorr);
-			if (albero == NULL) {
-			    G_fatal_error("avl_make error");
-			    return RLI_ERRORE;
-			}
-			m++;
-		    }
-		    else {
-			uc.val.dc = precCell;
-			ris = avl_add(&albero, uc, totCorr);
-			switch (ris) {
-			case AVL_ERR:
-			    {
-				G_fatal_error("avl_add error");
-				return RLI_ERRORE;
-			    }
-			case AVL_ADD:
-			    {
-				m++;
-				break;
-			    }
-			case AVL_PRES:
-			    {
-				break;
-			    }
-			default:
-			    {
-				G_fatal_error("avl_make unknown error");
-				return RLI_ERRORE;
-			    }
-			}
-		    }
-		    totCorr = 1;
-		}		/* endif not equal dcells */
-		else {		/*equal dcells */
-
-		    totCorr++;
-		}
-		precCell = corrCell;
+		/* total patch area */
+		area++;
 	    }
 
+	    if (!(G_is_null_value(&precCell, uc.t)) &&
+		corrCell == precCell) {
 
+		totCorr++;
+	    }
+	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+		     corrCell != precCell) {
+		
+		/* add precCell to search tree */
+		if (albero == NULL) {
+		    uc.val.dc = precCell;
+		    albero = avl_make(uc, totCorr);
+		    if (albero == NULL) {
+			G_fatal_error("avl_make error");
+			return RLI_ERRORE;
+		    }
+		    m++;
+		}
+		else {
+		    uc.val.dc = precCell;
+		    ris = avl_add(&albero, uc, totCorr);
+		    switch (ris) {
+		    case AVL_ERR:
+			{
+			    G_fatal_error("avl_add error");
+			    return RLI_ERRORE;
+			}
+		    case AVL_ADD:
+			{
+			    m++;
+			    break;
+			}
+		    case AVL_PRES:
+			{
+			    break;
+			}
+		    default:
+			{
+			    G_fatal_error("avl_make unknown error");
+			    return RLI_ERRORE;
+			}
+		    }
+		}
+		totCorr = 1;
+	    }		/* endif not equal cells */
+	    precCell = corrCell;
 	}
     }
 
-    /*last closing */
-    if (a != 0) {
+    /* last closing */
+    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.dc = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -475,70 +472,79 @@ double calculateD(area_des ad, int fd, char **par, double *result)
 	    }
 	}
     }
-    array = G_malloc(m * sizeof(AVL_tableRow));
-    if (array == NULL) {
-	G_fatal_error("malloc array failed");
-	return RLI_ERRORE;
-    }
-    tot = avl_to_array(albero, zero, array);
-    if (tot != m) {
-	G_warning("avl_to_array unaspected value. the result could be wrong");
-	return RLI_ERRORE;
+
+    if (area > 0) {
+	double alpha;
+	double pi;
+	double t;
+	double sum, sum2;
+
+	alpha = atof(par[0]);
+
+	array = G_malloc(m * sizeof(AVL_tableRow));
+	if (array == NULL) {
+	    G_fatal_error("malloc array failed");
+	    return RLI_ERRORE;
+	}
+	tot = avl_to_array(albero, zero, array);
+	if (tot != m) {
+	    G_warning("avl_to_array unexpected value. the result could be wrong");
+	    return RLI_ERRORE;
+	}
+
+	/* calculate renyi index */
+	sum = 0;
+	sum2 = 0;
+	for (i = 0; i < m; i++) {
+	    t = array[i]->tot;
+	    pi = t / area;
+	    sum += pow(pi, alpha);
+	    sum += pi;
+	}
+	G_free(array);
+
+	/* correction for numerical instability */
+	if (sum2 != 1)
+	    sum += 1 - sum2;
+
+	if ((alpha < 1 && sum < 1) || (alpha > 1 && sum > 1)) {
+	    G_warning("Renyi index calculation reached numerical instability. "
+	              "This can happen with alpha close to 1. The result will be set to zero.");
+	    sum = 1;
+	}
+
+	*result = (1 / (1 - alpha)) * log(sum);
     }
+    else
+	G_set_d_null_value(result, 1);
 
-    char *sval;
-
-    sval = par[0];
-    double alpha_double;
-
-    alpha_double = (double)atof(sval);
-    /* claculate index summary */
-    for (i = 0; i < m; i++) {
-	t = (double)(array[i]->tot);
-	p = t / area;
-	G_debug(1, "Valore p: %g, valore pow: %g", p, pow(p, alpha_double));
-	somma = somma + pow(p, alpha_double);
-    }
-
-    indice = (1 / (1 - alpha_double)) * log(somma);
-
-    if (isnan(indice) || isinf(indice)) {
-	indice = -1;
-    }
-
-    G_debug(1, "Valore somma: %g Valore indice: %g", somma, indice);
-
-    *result = indice;
-
-    G_free(array);
-    if (masked)
+    avl_destroy(albero);
+    if (masked) {
+	close(mask_fd);
 	G_free(mask_buf);
+    }
 
     return RLI_OK;
 }
 
 
-
-double calculateF(area_des ad, int fd, char **par, double *result)
+int calculateF(int fd, struct area_entry *ad, char **par, double *result)
 {
     FCELL *buf;
     FCELL corrCell;
     FCELL precCell;
 
     int i, j;
-    int mask_fd = -1, *mask_buf;
+    int mask_fd = -1, *mask_buf = NULL;
     int ris = 0;
     int masked = FALSE;
-    int a = 0;			/* a=0 if all cells are null */
+
     long m = 0;
     long tot = 0;
     long zero = 0;
-    long totCorr = 0;
-    double indice = 0;
-    double somma = 0;
-    double p = 0;
-    double area = 0;
-    double t;
+    long totCorr = 1;
+
+    long area = 0;
 
     avl_tree albero = NULL;
     AVL_table *array;
@@ -559,8 +565,6 @@ double calculateF(area_des ad, int fd, char **par, double *result)
     }
 
     G_set_f_null_value(&precCell, 1);
-
-
     for (j = 0; j < ad->rl; j++) {	/* for each row */
 	if (masked) {
 	    if (read(mask_fd, mask_buf, (ad->cl * sizeof(int))) < 0) {
@@ -571,72 +575,69 @@ double calculateF(area_des ad, int fd, char **par, double *result)
 
 	buf = RLI_get_fcell_raster_row(fd, j + ad->y, ad);
 
-
-	for (i = 0; i < ad->cl; i++) {	/* for each fcell in the row */
-
-	    area++;
+	for (i = 0; i < ad->cl; i++) {	/* for each cell in the row */
 	    corrCell = buf[i + ad->x];
 
-	    if (masked && mask_buf[i + ad->x] == 0) {
+	    if ((masked) && (mask_buf[i] == 0)) {
 		G_set_f_null_value(&corrCell, 1);
-		area--;
 	    }
 
 	    if (!(G_is_null_value(&corrCell, uc.t))) {
-		a = 1;
-		if (G_is_null_value(&precCell, uc.t)) {
-		    precCell = corrCell;
-		}
-		if (corrCell != precCell) {
-		    if (albero == NULL) {
-			uc.val.fc = precCell;
-			albero = avl_make(uc, totCorr);
-			if (albero == NULL) {
-			    G_fatal_error("avl_make error");
-			    return RLI_ERRORE;
-			}
-			m++;
-		    }
-		    else {
-			uc.val.fc = precCell;
-			ris = avl_add(&albero, uc, totCorr);
-			switch (ris) {
-			case AVL_ERR:
-			    {
-				G_fatal_error("avl_add error");
-				return RLI_ERRORE;
-			    }
-			case AVL_ADD:
-			    {
-				m++;
-				break;
-			    }
-			case AVL_PRES:
-			    {
-				break;
-			    }
-			default:
-			    {
-				G_fatal_error("avl_make unknown error");
-				return RLI_ERRORE;
-			    }
-			}
-		    }
-		    totCorr = 1;
-		}		/* endif not equal fcells */
-		else {		/*equal fcells */
-
-		    totCorr++;
-		}
-		precCell = corrCell;
+		/* total patch area */
+		area++;
 	    }
 
+	    if (!(G_is_null_value(&precCell, uc.t)) &&
+		corrCell == precCell) {
 
+		totCorr++;
+	    }
+	    else if (!(G_is_null_value(&precCell, uc.t)) &&
+		     corrCell != precCell) {
+		
+		/* add precCell to search tree */
+		if (albero == NULL) {
+		    uc.val.fc = precCell;
+		    albero = avl_make(uc, totCorr);
+		    if (albero == NULL) {
+			G_fatal_error("avl_make error");
+			return RLI_ERRORE;
+		    }
+		    m++;
+		}
+		else {
+		    uc.val.fc = precCell;
+		    ris = avl_add(&albero, uc, totCorr);
+		    switch (ris) {
+		    case AVL_ERR:
+			{
+			    G_fatal_error("avl_add error");
+			    return RLI_ERRORE;
+			}
+		    case AVL_ADD:
+			{
+			    m++;
+			    break;
+			}
+		    case AVL_PRES:
+			{
+			    break;
+			}
+		    default:
+			{
+			    G_fatal_error("avl_make unknown error");
+			    return RLI_ERRORE;
+			}
+		    }
+		}
+		totCorr = 1;
+	    }		/* endif not equal cells */
+	    precCell = corrCell;
 	}
     }
 
-    /*last closing */
-    if (a != 0) {
+    /* last closing */
+    if (area > 0 && !(G_is_null_value(&precCell, uc.t))) {
 	if (albero == NULL) {
 	    uc.val.fc = precCell;
 	    albero = avl_make(uc, totCorr);
@@ -673,45 +674,56 @@ double calculateF(area_des ad, int fd, char **par, double *result)
 	}
     }
 
-    array = G_malloc(m * sizeof(AVL_tableRow));
-    if (array == NULL) {
-	G_fatal_error("malloc array failed");
-	return RLI_ERRORE;
-    }
-    tot = avl_to_array(albero, zero, array);
-    if (tot != m) {
-	G_warning("avl_to_array unaspected value. the result could be wrong");
-	return RLI_ERRORE;
+    if (area > 0) {
+	double alpha;
+	double pi;
+	double t;
+	double sum, sum2;
+
+	alpha = atof(par[0]);
+
+	array = G_malloc(m * sizeof(AVL_tableRow));
+	if (array == NULL) {
+	    G_fatal_error("malloc array failed");
+	    return RLI_ERRORE;
+	}
+	tot = avl_to_array(albero, zero, array);
+	if (tot != m) {
+	    G_warning("avl_to_array unexpected value. the result could be wrong");
+	    return RLI_ERRORE;
+	}
+
+	/* calculate renyi index */
+	sum = 0;
+	sum2 = 0;
+	for (i = 0; i < m; i++) {
+	    t = array[i]->tot;
+	    pi = t / area;
+	    sum += pow(pi, alpha);
+	    sum2 += pi;
+	}
+	G_free(array);
+
+	/* correction for numerical instability */
+	if (sum2 != 1)
+	    sum += 1 - sum2;
+
+	if ((alpha < 1 && sum < 1) || (alpha > 1 && sum > 1)) {
+	    G_warning("Renyi index calculation reached numerical instability. "
+	              "This can happen with alpha close to 1. The result will be set to zero.");
+	    sum = 1;
+	}
+
+	*result = (1 / (1 - alpha)) * log(sum);
     }
+    else
+	G_set_d_null_value(result, 1);
 
-    char *sval;
-
-    sval = par[0];
-    double alpha_double;
-
-    alpha_double = (double)atof(sval);
-    /* calculate index summary */
-    for (i = 0; i < m; i++) {
-	t = (double)(array[i]->tot);
-	p = t / area;
-	G_debug(1, "Valore p: %g, valore pow: %g", p, pow(p, alpha_double));
-	somma = somma + pow(p, alpha_double);
-    }
-
-    indice = (1 / (1 - alpha_double)) * log(somma);
-
-    if (isnan(indice) || isinf(indice)) {
-	indice = -1;
-    }
-
-    G_debug(1, "Valore somma: %g Valore indice: %g", somma, indice);
-
-    *result = indice;
-
-    G_free(array);
-    if (masked)
+    avl_destroy(albero);
+    if (masked) {
+	close(mask_fd);
 	G_free(mask_buf);
+    }
 
     return RLI_OK;
-
 }
