@@ -105,7 +105,7 @@ int main(int argc, char *argv[])
     G_gisinit(argv[0]);
 
     module = G_define_module();
-    module->keywords = _("raster");
+    module->keywords = _("raster, statistics");
     module->description =
 	_("Makes each cell category value a "
 	  "function of the category values assigned to the cells "
