@@ -565,8 +565,8 @@ int main(int argc, char *argv[])
     G_gisinit(argv[0]);
 
     module = G_define_module();
-    module->keywords = _("raster3d, statistics");
-    module->description = _("Generates volume statistics for raster3d maps.");
+    module->keywords = _("raster3d, voxel, statistics");
+    module->description = _("Generates volume statistics for 3D raster maps.");
 
     /* Define the different options */
 
@@ -577,7 +577,7 @@ int main(int argc, char *argv[])
     steps->type = TYPE_INTEGER;
     steps->required = NO;
     steps->answer = "20";
-    steps->description = _("Number of sub-ranges to collect stats from");
+    steps->description = _("Number of subranges to collect stats from");
 
 
     equal = G_define_flag();
@@ -608,14 +608,14 @@ int main(int argc, char *argv[])
     infile = inputfile->answer;
 
     if (NULL == G_find_grid3(infile, ""))
-	G3d_fatalError(_("Requested g3d map <%s> not found"), infile);
+	G3d_fatalError(_("3D raster map <%s> not found"), infile);
 
     map =
 	G3d_openCellOld(infile, G_find_grid3(infile, ""), &region,
 			G3D_TILE_SAME_AS_FILE, G3D_USE_CACHE_DEFAULT);
 
     if (map == NULL)
-	G3d_fatalError(_("Error opening g3d map <%s>"), infile);
+	G3d_fatalError(_("Unable to open 3D raster map <%s>"), infile);
 
     map_type = G3d_tileTypeMap(map);
 
