@@ -7,8 +7,6 @@
 #define WORLD
 #endif
 
-WORLD int gQuietly;
-WORLD int gOverwrite;
 WORLD int gCopy_atts;
 WORLD int gAsciiout;
 WORLD char gAscii_type;
