@@ -9,9 +9,11 @@
 #endif
 
 static void make_head(struct Map_info *);
+static int find_next_header_variable(struct dxf_file *);
 
 static BOUND_BOX ext, dxf_ext;
 
+/* returns 1 on success, otherwise 0 */
 int dxf_to_vect(struct dxf_file *dxf, struct Map_info *Map)
 {
     int code;
@@ -22,18 +24,20 @@ int dxf_to_vect(struct dxf_file *dxf, struct Map_info *Map)
 	code = dxf_get_code(dxf);
 	while (code != 0) {
 	    if (code == -2)	/* EOF */
-		return -1;
+		return 0;
 
 	    /* only looking for header groups (code == 9) */
-	    if (code != 9)
+	    if (code != 9) {
+		code = find_next_header_variable(dxf);
 		continue;
+	    }
 
 	    if (strcmp(dxf_buf, "$EXTMAX") == 0) {
-		/* read in lines and processes information until a 9
+		/* read in lines and process information until a 9
 		 * or a 0 is read in */
 		while ((code = dxf_get_code(dxf)) != 9 && code != 0) {
 		    if (code == -2)	/* EOF */
-			return -1;
+			return 0;
 
 		    switch (code) {
 		    case 10:
@@ -54,11 +58,11 @@ int dxf_to_vect(struct dxf_file *dxf, struct Map_info *Map)
 		}
 	    }
 	    else if (strcmp(dxf_buf, "$EXTMIN") == 0) {
-		/* read in lines and processes information until a 9
+		/* read in lines and process information until a 9
 		 * or a 0 is read in */
 		while ((code = dxf_get_code(dxf)) != 9 && code != 0) {
 		    if (code == -2)	/* EOF */
-			return -1;
+			return 0;
 
 		    switch (code) {
 		    case 10:
@@ -77,12 +81,8 @@ int dxf_to_vect(struct dxf_file *dxf, struct Map_info *Map)
 		    }
 		}
 	    }
-	    else {
-		while ((code = dxf_get_code(dxf)) != 9 && code != 0) {
-		    if (code == -2)	/* EOF */
-			return -1;
-		}
-	    }
+	    else
+		code = find_next_header_variable(dxf);
 
 	    if (bounds == 6)
 		break;
@@ -141,16 +141,32 @@ int dxf_to_vect(struct dxf_file *dxf, struct Map_info *Map)
     G_free(ypnts);
     G_free(zpnts);
 
-    if (!flag_list) {
-	Vect_destroy_line_struct(Points);
-	write_done(Map);
-	if (found_layers)
-	    make_head(Map);
+    if (flag_list)
+	return 1;
+
+    Vect_destroy_line_struct(Points);
+
+    if (write_done(Map)) {
+	make_head(Map);
+	return 1;
     }
 
     return 0;
 }
 
+int find_next_header_variable(struct dxf_file *dxf)
+{
+    int code;
+
+    /* code  9: header variable
+     * code  0: ENDSEC
+     * code -2: EOF
+     */
+    while ((code = dxf_get_code(dxf)) != 9 && code != 0 && code != -2) ;
+
+    return code;
+}
+
 int check_ext(double x, double y, double z)
 {
     if (x < ext.W)
