@@ -3,6 +3,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <math.h>
+#include <grass/gis.h>
+#include <grass/glocale.h>
 #include "list.h"
 #include "mapcalc.h"
 
