@@ -1,7 +1,7 @@
 /*
  ****************************************************************************
  *
- * MODULE:       s/v.vol.rst: program for 3D(volume) interpolation and geometry
+ * MODULE:       v.vol.rst: program for 3D (volume) interpolation and geometry
  *               analysis from scattered point data using regularized spline
  *               with tension
  *
@@ -11,9 +11,9 @@
  *               GRASS 4.2, GRASS 5.0 version and modifications:
  *               H. Mitasova,  I. Kosinovsky, D. Gerdes, J. Hofierka
  *
- * PURPOSE:      s/v.vol.rst interpolates the values to 3-dimensional grid from
+ * PURPOSE:      v.vol.rst interpolates the values to 3-dimensional grid from
  *               point data (climatic stations, drill holes etc.) given in a
- *               sites file named input. Output grid3 file is elev. 
+ *               3D vector point input. Output grid3 file is elev. 
  *               Regularized spline with tension is used for the
  *               interpolation.
  *
@@ -21,8 +21,8 @@
  *               I. Kosinovsky, D. Gerdes, J. Hofierka
  *
  *               This program is free software under the GNU General Public
- *              License (>=v2). Read the file COPYING that comes with GRASS
- *              for details.
+ *               License (>=v2). Read the file COPYING that comes with GRASS
+ *               for details.
  *
  *****************************************************************************/
 
@@ -444,7 +444,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -467,7 +467,8 @@ int OUTGR()
 	if (G3d_closeCell(cf1) == 0) {
 	    sprintf(buff, "Error closing output file %s ", outz);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), outz);
     }
 
   /*** Write out the gradient results ***/
@@ -495,7 +496,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -518,7 +519,8 @@ int OUTGR()
 	if (G3d_closeCell(cf2) == 0) {
 	    sprintf(buff, "Error closing output file %s ", gradient);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), gradient);
     }
 
   /*** Write out aspect1 results ***/
@@ -546,7 +548,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -569,7 +571,8 @@ int OUTGR()
 	if (G3d_closeCell(cf3) == 0) {
 	    sprintf(buff, "Error closing output file %s ", aspect1);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), aspect1);
     }
 
   /*** Write out aspect2 results ***/
@@ -597,7 +600,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -620,7 +623,8 @@ int OUTGR()
 	if (G3d_closeCell(cf4) == 0) {
 	    sprintf(buff, "Error closing output file %s ", aspect2);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), aspect2);
     }
 
   /*** Write out ncurv results ***/
@@ -648,7 +652,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -671,7 +675,8 @@ int OUTGR()
 	if (G3d_closeCell(cf5) == 0) {
 	    sprintf(buff, "Error closing output file %s ", ncurv);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), ncurv);
     }
 
   /*** Write out gcurv results ***/
@@ -699,7 +704,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -722,7 +727,8 @@ int OUTGR()
 	if (G3d_closeCell(cf6) == 0) {
 	    sprintf(buff, "Error closing output file %s ", gcurv);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), gcurv);
     }
 
   /*** Write mcurv results ***/
@@ -750,7 +756,7 @@ int OUTGR()
 	    for (y = nsizr - 1; y >= 0; y--) {	/* changed by AV */
 		for (x = 0; x < nsizc; x++) {
 		    if (maskmap != NULL)
-			bmask = BM_get(bitmask, x, y);
+			bmask = BM_get(bitmask, x, nsizr - y - 1);
 		    else
 			bmask = 1;
 		    value = data[cnt];
@@ -773,7 +779,8 @@ int OUTGR()
 	if (G3d_closeCell(cf7) == 0) {
 	    sprintf(buff, "Error closing output file %s ", mcurv);
 	    clean_fatal_error(buff);
-	}
+	} else
+            G_message(_("3D raster map <%s> created"), mcurv);
     }
 
     G_free(data);
